@@ -46,8 +46,32 @@ class SnowflakeDataSource(DataSource):
         DataType.BOOLEAN: "BOOLEAN",
     }
 
-    NUMERIC_TYPES_FOR_PROFILING = ["FLOAT", "NUMBER", "INT"]
-    TEXT_TYPES_FOR_PROFILING = ["TEXT"]
+    NUMERIC_TYPES_FOR_PROFILING = [
+        "FLOAT",
+        "NUMBER",
+        "INT",
+        "DECIMAL",
+        "NUMERIC",
+        "INTEGER",
+        "BIGINT",
+        "SMALLINT",
+        "TINYINT",
+        "FLOAT4",
+        "FLOAT8",
+        "REAL",
+    ]
+    TEXT_TYPES_FOR_PROFILING = [
+        "TEXT",
+        "VARCHAR",
+        "CHAR",
+        "CHARACTER",
+        "NCHAR",
+        "STRING",
+        "NVARCHAR",
+        "NVARCHAR2",
+        "CHAR VARYING",
+        "NCHAR VARYING",
+    ]
 
     def __init__(self, logs: Logs, data_source_name: str, data_source_properties: dict):
         super().__init__(logs, data_source_name, data_source_properties)
@@ -89,6 +113,7 @@ class SnowflakeDataSource(DataSource):
             private_key=self.__get_private_key(),
             client_prefetch_threads=self.client_prefetch_threads,
             authenticator=self.authenticator,
+            application="Soda",
         )
 
     def __get_private_key(self):
